@@ -8,7 +8,7 @@ import numpy as np
 from mmap_ninja import base
 
 
-def mkdir(out_dir: Union[str, Path]) -> Path:
+def _create_if_not_exists(out_dir: Union[str, Path]) -> Path:
     """
     A helper mkdir that creates the directory if it doesn't exist.
     Returns the path to the directory.created.
@@ -18,12 +18,7 @@ def mkdir(out_dir: Union[str, Path]) -> Path:
     return out_dir
 
 
-def save_mmap_kwargs(
-        out_dir: Path,
-        dtype: Union[np.dtype, str],
-        shape: Sequence[int],
-        order: str
-) -> None:
+def _save_mmap_kwargs(out_dir: Path, dtype: Union[np.dtype, str], shape: Sequence[int], order: str) -> None:
     """
     Persists the arguments needed for initializing a ``np.memmap``, so that the user does not have to specify them.
 
@@ -33,32 +28,32 @@ def save_mmap_kwargs(
     :param order: A string, representing the order - ``"F"`` or ``"C"``
     :return:
     """
-    out_dir = mkdir(out_dir)
-    base.str_to_file(np.dtype(dtype).name, out_dir / f'dtype.ninja')
-    base.shape_to_file(shape, out_dir / f'shape.ninja')
-    base.str_to_file(order, out_dir / f'order.ninja')
+    out_dir = _create_if_not_exists(out_dir)
+    base._str_to_file(np.dtype(dtype).name, out_dir / f"dtype.ninja")
+    base._shape_to_file(shape, out_dir / f"shape.ninja")
+    base._str_to_file(order, out_dir / f"order.ninja")
 
 
-def read_mmap_kwargs(out_dir: Path) -> Dict:
+def _read_mmap_kwargs(out_dir: Path) -> Dict:
     """
     Reads already persisted arguments needed for opening a ``np.memmap``.
 
     :param out_dir: The persistence directory of the ``np.memmap``.
     :return: A dictionary representing the ``kwargs`` needed for initialization.
     """
-    out_dir = mkdir(out_dir)
+    out_dir = _create_if_not_exists(out_dir)
     return {
-        'dtype': base.file_to_str(out_dir / 'dtype.ninja'),
-        'shape': base.file_to_shape(out_dir / 'shape.ninja'),
-        'order': base.file_to_str(out_dir / 'order.ninja')
+        "dtype": base._file_to_str(out_dir / "dtype.ninja"),
+        "shape": base._file_to_shape(out_dir / "shape.ninja"),
+        "order": base._file_to_str(out_dir / "order.ninja"),
     }
 
 
-def empty(
-        out_dir: Union[str, Path],
-        dtype: Union[str, np.dtype],
-        shape: Sequence[int],
-        order: str
+def _empty(
+    out_dir: Union[str, Path],
+    dtype: Union[str, np.dtype],
+    shape: Sequence[int],
+    order: str,
 ) -> np.memmap:
     """
     Creates an empty ``np.memmap``
@@ -69,20 +64,13 @@ def empty(
     :param order: The order, either ``"C"`` or ``"F"``
     :return:
     """
-    out_dir = mkdir(out_dir)
-    save_mmap_kwargs(out_dir, dtype, shape, order)
-    memmap = np.memmap(str(out_dir / 'data.ninja'),
-                       mode='w+',
-                       dtype=dtype,
-                       shape=shape,
-                       order=order)
+    out_dir = _create_if_not_exists(out_dir)
+    _save_mmap_kwargs(out_dir, dtype, shape, order)
+    memmap = np.memmap(str(out_dir / "data.ninja"), mode="w+", dtype=dtype, shape=shape, order=order)
     return memmap
 
 
-def from_ndarray(
-        out_dir: Union[str, Path],
-        arr: np.ndarray
-) -> np.memmap:
+def from_ndarray(out_dir: Union[str, Path], arr: np.ndarray) -> np.memmap:
     """
     Initializes a memory map, in which all samples should be of the same shape
 
@@ -91,26 +79,22 @@ def from_ndarray(
     :return: The memory mapped file
     """
     arr = np.asarray(arr)
-    out_dir = mkdir(out_dir)
+    out_dir = _create_if_not_exists(out_dir)
     dtype = arr.dtype
     shape = arr.shape
-    order = 'F' if np.isfortran(arr) else 'C'
-    memmap = np.memmap(str(out_dir / 'data.ninja'),
-                       mode='w+',
-                       dtype=dtype,
-                       shape=shape,
-                       order=order)
+    order = "F" if np.isfortran(arr) else "C"
+    memmap = np.memmap(str(out_dir / "data.ninja"), mode="w+", dtype=dtype, shape=shape, order=order)
     memmap[:] = arr
-    save_mmap_kwargs(out_dir, dtype, shape, order)
+    _save_mmap_kwargs(out_dir, dtype, shape, order)
     return memmap
 
 
-def write_samples(
-        memmap: Optional[np.memmap],
-        out_dir: Path,
-        samples: Sequence[np.ndarray],
-        start: int,
-        total: int
+def _write_samples(
+    memmap: Optional[np.memmap],
+    out_dir: Path,
+    samples: Sequence[np.ndarray],
+    start: int,
+    total: int,
 ) -> Tuple[np.memmap, int]:
     """
     Writes samples starting from a given start index in the memory map.
@@ -127,24 +111,22 @@ def write_samples(
     if memmap is None:
         dtype = arr.dtype
         shape = (total,) + arr.shape[1:]
-        order = 'F' if np.isfortran(arr) else 'C'
-        memmap = np.memmap(str(out_dir / 'data.ninja'),
-                           mode='w+',
-                           dtype=dtype,
-                           shape=shape,
-                           order=order)
+        order = "F" if np.isfortran(arr) else "C"
+        memmap = np.memmap(
+            str(out_dir / "data.ninja"),
+            mode="w+",
+            dtype=dtype,
+            shape=shape,
+            order=order,
+        )
     end = start + len(samples)
     memmap[start:end] = arr
     return memmap, end
 
 
-def from_generator(sample_generator,
-                   out_dir: Union[str, Path],
-                   batch_size: int,
-                   n: int,
-                   verbose=False) -> np.memmap:
+def from_generator(out_dir: Union[str, Path], sample_generator, batch_size: int, n: int, verbose=False) -> np.memmap:
     """
-    Create a numpy array from a sample generator.
+    Create a numpy memory-map from a sample generator.
 
     :param sample_generator: A generator of the samples
     :param out_dir: The output directory
@@ -153,25 +135,26 @@ def from_generator(sample_generator,
     :param verbose: Whether to show the progress bar.
     :return:
     """
-    out_dir = mkdir(out_dir)
+    out_dir = _create_if_not_exists(out_dir)
     samples = []
     memmap = None
     start = 0
     if verbose:
         from tqdm import tqdm
+
         sample_generator = tqdm(sample_generator, total=n)
     for sample in sample_generator:
         samples.append(sample)
         if len(samples) % batch_size != 0:
             continue
-        memmap, start = write_samples(memmap, out_dir, samples, start, n)
+        memmap, start = _write_samples(memmap, out_dir, samples, start, n)
         samples = []
     if len(samples) > 0:
-        memmap, start = write_samples(memmap, out_dir, samples, start, n)
+        memmap, start = _write_samples(memmap, out_dir, samples, start, n)
     return memmap
 
 
-def open_existing(out_dir: Union[str, Path], mode='r') -> np.memmap:
+def open_existing(out_dir: Union[str, Path], mode="r") -> np.memmap:
     """
     Open an already existing numpy array.
 
@@ -180,10 +163,8 @@ def open_existing(out_dir: Union[str, Path], mode='r') -> np.memmap:
     :return: The ``np.memmap`` object.
     """
     out_dir = Path(out_dir)
-    kwargs = read_mmap_kwargs(out_dir)
-    memmap = np.memmap(str(out_dir / 'data.ninja'),
-                       mode=mode,
-                       **kwargs)
+    kwargs = _read_mmap_kwargs(out_dir)
+    memmap = np.memmap(str(out_dir / "data.ninja"), mode=mode, **kwargs)
     return memmap
 
 
@@ -197,17 +178,18 @@ def extend_dir(out_dir: Union[str, Path], arr: np.ndarray) -> None:
     """
     arr = np.asarray(arr)
     out_dir = Path(out_dir)
-    kwargs = read_mmap_kwargs(out_dir)
-    shape = kwargs['shape']
-    order = kwargs['order']
-    dtype = np.dtype(kwargs['dtype'])
-    assert shape[1:] == arr.shape[1:], f'Trying to append samples with incorrect shape: {arr.shape[1:]}, ' \
-                                       f'expected: {shape[1:]}'
-    with open(out_dir / 'data.ninja', 'ab') as data_file:
+    kwargs = _read_mmap_kwargs(out_dir)
+    shape = kwargs["shape"]
+    order = kwargs["order"]
+    dtype = np.dtype(kwargs["dtype"])
+    assert shape[1:] == arr.shape[1:], (
+        f"Trying to append samples with incorrect shape: {arr.shape[1:]}, " f"expected: {shape[1:]}"
+    )
+    with open(out_dir / "data.ninja", "ab") as data_file:
         data_file.write(arr.astype(dtype).tobytes(order=order))
         data_file.flush()
     new_shape = (shape[0] + arr.shape[0], *shape[1:])
-    base.shape_to_file(new_shape, out_dir / f'shape.ninja')
+    base._shape_to_file(new_shape, out_dir / f"shape.ninja")
 
 
 def extend(np_mmap: np.memmap, arr: np.ndarray) -> None:
@@ -230,7 +212,7 @@ class NumpyBytesSlices:
     shapes: List[Tuple[int]]
 
 
-def lists_of_ndarrays_to_bytes(lists: Sequence[np.ndarray], dtype) -> NumpyBytesSlices:
+def _lists_of_ndarrays_to_bytes(lists: Sequence[np.ndarray], dtype) -> NumpyBytesSlices:
     """
     Converts a list of numpy arrays into bytes.
 
